"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getIdentity = exports.default = void 0;
var _api = require("@webiny/api");
var _apiCognitoAuthenticator = require("@webiny/api-cognito-authenticator");
const getIdentity = ({
  identityType,
  token
}) => {
  // We ensure `undefined` doesn't end up in the `displayName` property.
  // If first name and last name is not present, we end up with an empty string.
  const {
    given_name = null,
    family_name = null,
    email = null,
    preferred_username = null
  } = token;
  const displayName = [given_name, family_name].filter(Boolean).join(" ").trim() || null;
  return {
    id: token["custom:id"] || token["sub"] || null,
    type: identityType,
    displayName,
    email: preferred_username || email,
    firstName: given_name,
    lastName: family_name
  };
};
exports.getIdentity = getIdentity;
var _default = config => {
  const cognitoAuthenticator = (0, _apiCognitoAuthenticator.createAuthenticator)({
    region: config.region,
    userPoolId: config.userPoolId
  });
  return new _api.ContextPlugin(({
    authentication
  }) => {
    authentication.addAuthenticator(async token => {
      const tokenObj = await cognitoAuthenticator(token);
      if (!tokenObj) {
        return null;
      }
      if (typeof config.getIdentity === "function") {
        return config.getIdentity({
          identityType: config.identityType,
          token: tokenObj
        });
      }
      return getIdentity({
        identityType: config.identityType,
        token: tokenObj
      });
    });
  });
};
exports.default = _default;

//# sourceMappingURL=index.js.map